##  Activating and Deactivating Safety Net
The safety net is enabled by default and can be toggled on or off in the Manage Survey section. You can also set a different threshold from the drop-down list.
Applicability: The halting of notifications applies only during the regular 'check for changes' cycles, and it does not affect notifications intended to be sent when initiating a survey run.
